==> angr-9.0.4885.tar.gz: angr-9.0.4885/angr/analyses/decompiler/decompilation_options.py <==
# decompilation options

from collections import defaultdict


class DecompilationOption:
    def __init__(self, name, description, value_type, cls, param, value_range=None, category="General",
                 default_value=None):
        self.name = name
        self.description = description
        self.value_type = value_type
        self.cls = cls
        self.param = param
        self.value_range = value_range
        self.category = category
        self.default_value = default_value


O = DecompilationOption

options = [
    O(
        "Remove dead memdefs",
        "Allow the decompiler to remove memory definitions (such as stack variables) that are deemed dead. Generally, "
        "enabling this option will generate cleaner pseudocode; But when prior analyses go wrong, angr may miss "
        "certain uses to a memory definition, which may cause the removal of a memory definition that is in use.",
        bool,
        "clinic",
        "remove_dead_memdefs",
        category="Data flows",
        default_value=True,
    ),
    O(
        "Display exception edges (experimental)",
        "Decompile and display exception handling code. Enabling this option generally degrades the readability of the "
        "pseudo code. This is still an experimental feature.",
        bool,
        "clinic",
        "exception_edges",
        category="Graph",
        default_value=False,
    )
]

options_by_category = defaultdict(list)

for o in options:
    options_by_category[o.category].append(o)

==> angr-9.0.7912.tar.gz: angr-9.0.7912/angr/analyses/decompiler/decompilation_options.py <==
# decompilation options

from collections import defaultdict


class DecompilationOption:
    def __init__(self, name, description, value_type, cls, param, value_range=None, category="General",
                 default_value=None, clears_cache=True):
        self.name = name
        self.description = description
        self.value_type = value_type
        self.cls = cls
        self.param = param
        self.value_range = value_range
        self.category = category
        self.default_value = default_value
        self.clears_cache = clears_cache


O = DecompilationOption

options = [
    O(
        "Remove dead memdefs",
        "Allow the decompiler to remove memory definitions (such as stack variables) that are deemed dead. Generally, "
        "enabling this option will generate cleaner pseudocode; But when prior analyses go wrong, angr may miss "
        "certain uses to a memory definition, which may cause the removal of a memory definition that is in use.",
        bool,
        "clinic",
        "remove_dead_memdefs",
        category="Data flows",
        default_value=True,
    ),
    O(
        "Display exception edges (experimental)",
        "Decompile and display exception handling code. Enabling this option generally degrades the readability of the "
        "pseudo code. This is still an experimental feature.",
        bool,
        "clinic",
        "exception_edges",
        category="Graph",
        default_value=False,
    ),
    O(
        "Show casts",
        "Disabling this option will blindly remove all C typecast constructs from pseudocode output.",
        bool,
        "codegen",
        "show_casts",
        category="Display",
        default_value=True,
        clears_cache=False,
    ),
    O(
        "Braces on own lines",
        "Highly controversial. Disable this to see \"} else {\".",
        bool,
        "codegen",
        "braces_on_own_lines",
        category="Display",
        default_value=True,
        clears_cache=False,
    )
]

options_by_category = defaultdict(list)

for o in options:
    options_by_category[o.category].append(o)
